@@ -62,7 +62,7 @@ struct Parse_Options_s
 {
 	int verbosity;         /* Level of detail to give about the computation 0 */
 	int linkage_limit;     /* The maximum number of linkages processed 10000 */
-	int disjunct_cost;     /* Max disjunct cost to allow */
+	float disjunct_cost;   /* Max disjunct cost to allow */
 	int min_null_count;    /* The minimum number of null links to allow */
 	int max_null_count;    /* The maximum number of null links to allow */
 	int null_block;        /* consecutive blocks of this many words are
@@ -86,6 +86,7 @@ struct Parse_Options_s
 	int display_walls;
 	int display_union;            /* print squashed version of linkage with conjunction? */
 	int allow_null;               /* true if we allow null links in parsing */
+	int use_cluster_disjuncts;    /* if true, atttempt using a borader list of disjuncts */
 	int echo_on;                  /* true if we should echo the input sentence */
 	int batch_mode;               /* if true, process sentences non-interactively */
 	int panic_mode;               /* if true, parse in "panic mode" after all else fails */
@@ -99,12 +100,12 @@ struct Parse_Options_s
 	int display_senses;           /* if true, sense candidates are printed out */
 };
 
-typedef struct
+struct Connector_set_s
 {
 	Connector ** hash_table;
 	int          table_size;
 	int          is_defined;  /* if 0 then there is no such set */
-} Connector_set;
+};
 
 struct Dictionary_s
 {
