@@ -93,6 +93,7 @@ Parse_Options parse_options_create(void)
 	po->display_walls = FALSE;
 	po->display_union = FALSE;
 	po->allow_null = TRUE;
+	po->use_cluster_disjuncts = FALSE;
 	po->echo_on = FALSE;
 	po->batch_mode = FALSE;
 	po->panic_mode = FALSE;
@@ -161,9 +162,15 @@ int parse_options_get_linkage_limit(Parse_Options opts) {
 void parse_options_set_disjunct_cost(Parse_Options opts, int dummy) {
 	opts->disjunct_cost = dummy;
 }
+void parse_options_set_disjunct_costf(Parse_Options opts, float dummy) {
+	opts->disjunct_cost = dummy;
+}
 int parse_options_get_disjunct_cost(Parse_Options opts) {
 	return opts->disjunct_cost;
 }
+float parse_options_get_disjunct_costf(Parse_Options opts) {
+	return opts->disjunct_cost;
+}
 
 void parse_options_set_min_null_count(Parse_Options opts, int val) {
 	opts->min_null_count = val;
@@ -275,6 +282,14 @@ int parse_options_get_allow_null(Parse_Options opts) {
 	return opts->allow_null;
 }
 
+void parse_options_set_use_cluster_disjuncts(Parse_Options opts, int dummy) {
+	opts->use_cluster_disjuncts = dummy;
+}
+
+int parse_options_get_use_cluster_disjuncts(Parse_Options opts) {
+	return opts->use_cluster_disjuncts;
+}
+
 void parse_options_set_screen_width(Parse_Options opts, int dummy) {
 	opts->screen_width = dummy;
 }
@@ -1022,6 +1037,23 @@ Sentence sentence_create(const char *input_string, Dictionary dict)
 	return sent;
 }
 
+/* XXX Extreme hack alert -- English-language words are used
+ * completely naked in the C source code!!! FIXME !!!!
+ */
+static void set_is_conjunction(Sentence sent)
+{
+	int w;
+	char * s;
+	for (w=0; w<sent->length; w++) {
+		s = sent->word[w].string;
+		sent->is_conjunction[w] = 
+			(strcmp(s, "and")==0) ||
+			(strcmp(s, "or" )==0) ||
+			(strcmp(s, "but")==0) ||
+			(strcmp(s, "nor")==0);
+	}
+}
+
 static int split_sentence(Sentence sent, Parse_Options opts)
 {
 	int i;
@@ -1537,15 +1569,41 @@ Sentence linkage_get_sentence(Linkage linkage)
 	return linkage->sent;
 }
 
-const char * linkage_get_disjunct(Linkage linkage, int w)
+const char * linkage_get_disjunct_str(Linkage linkage, int w)
 {
+	Disjunct *dj;
+
 	if (NULL == linkage->info->disjunct_list_str)
 	{
 		lg_compute_disjunct_strings(linkage->sent, linkage->info);
 	}
+
+	/* dj will be null if the words wasn't used in the parse. */
+	dj = linkage->sent->parse_info->chosen_disjuncts[w];
+	if (NULL == dj) return "";
+
 	return linkage->info->disjunct_list_str[w];
 }
 
+double linkage_get_disjunct_cost(Linkage linkage, int w)
+{
+	Disjunct *dj = linkage->sent->parse_info->chosen_disjuncts[w];
+
+	/* dj may be null, if the word didn't participate in the parse. */
+	if (dj) return dj->cost;
+	return 0.0;
+}
+
+double linkage_get_disjunct_corpus_score(Linkage linkage, int w)
+{
+	Disjunct *dj = linkage->sent->parse_info->chosen_disjuncts[w];
+
+	/* dj may be null, if the word didn't participate in the parse. */
+	if (NULL == dj) return 99.999;
+
+	return lg_corpus_disjunct_score(linkage, w); 
+}
+
 const char * linkage_get_word(Linkage linkage, int w)
 {
 	return linkage->word[w];
@@ -1558,7 +1616,7 @@ int linkage_unused_word_cost(Linkage linkage)
 
 int linkage_disjunct_cost(Linkage linkage)
 {
-	return linkage->info->disjunct_cost;
+	return (int) floorf(linkage->info->disjunct_cost);
 }
 
 int linkage_and_cost(Linkage linkage)
