@@ -14,6 +14,7 @@
 #include <sqlite3.h>
 #include "corpus.h"
 #include "../api-structures.h"
+#include "../disjuncts.h"
 #include "../utilities.h"
 
 struct corpus_s
@@ -69,8 +70,8 @@ Corpus * lg_corpus_new(void)
 	c->dbname = NULL;
 
 	/* dbname = "/link-grammar/data/en/sql/disjuncts.db"; */
-
-	c->dbconn = object_open("sql/disjuncts.db", db_file_open, c);
+#define DBNAME "sql/disjuncts.db"
+	c->dbconn = object_open(DBNAME, db_file_open, c);
 	if (NULL == c->dbconn)
 	{
 		/* Very weird .. but if the database is not found, then sqlite
@@ -79,11 +80,13 @@ Corpus * lg_corpus_new(void)
 		 */
 		if (SQLITE_CANTOPEN == c->rc)
 		{
-			prt_error("Warning: Can't open database: File not found\n");
+			prt_error("Warning: Can't open database: File not found\n"
+			          "\tWas looking for: " DBNAME);
 		}
 		else
 		{ 
-			prt_error("Warning: Can't open database: %s\n",
+			prt_error("Warning: Can't open database: %s\n"
+			          "\tWas looking for: " DBNAME,
 				sqlite3_errmsg(c->dbconn));
 		}
 		return c;
@@ -205,6 +208,7 @@ static double get_disjunct_score(Corpus *corp,
 	else
 	{
 		val = sqlite3_column_double(corp->rank_query, 0);
+		if (LOW_SCORE < val) val = LOW_SCORE;
 #ifdef DEBUG
 		printf ("Word=%s dj=%s score=%f\n", inflected_word, disjunct, val);
 #endif
@@ -252,12 +256,15 @@ void lg_corpus_score(Sentence sent, Linkage_info *lifo)
 	 * word 0. */
 	for (w=1; w<nwords; w++)
 	{
-		/* If the word is not inflected, then sent->word[w].d is NULL */
-		if (sent->word[w].d)
-			infword = sent->word[w].d->string;
-		else
-			infword = sent->word[w].string;
+		Disjunct *disj = sent->parse_info->chosen_disjuncts[w];
 
+		/* disj is NULL if word did not participate in parse */
+		if (NULL == disj)
+		{
+			tot_score += LOW_SCORE;
+			continue;
+		}
+		infword = disj->string;
 		djstr = lifo->disjunct_list_str[w];
 		tot_score += get_disjunct_score(corp, infword, djstr);
 	}
@@ -268,6 +275,31 @@ void lg_corpus_score(Sentence sent, Linkage_info *lifo)
 	lifo->corpus_cost = tot_score;
 }
 
+double lg_corpus_disjunct_score(Linkage linkage, int w)
+{
+	double score;
+	const char *infword, *djstr;
+	Sentence sent = linkage->sent;
+	Linkage_info *lifo = linkage->info;
+	Corpus *corp = sent->dict->corpus;
+	Disjunct *disj;
+
+	/* No-op if the database is not open */
+	if (NULL == corp->dbconn) return LOW_SCORE;
+
+	/* disj is NULL if word did not participate in parse */
+	disj = sent->parse_info->chosen_disjuncts[w];
+	if (NULL == disj) return LOW_SCORE;
+
+	lg_compute_disjunct_strings(sent, lifo);
+
+	infword = disj->string;
+	djstr = lifo->disjunct_list_str[w];
+	score = get_disjunct_score(corp, infword, djstr);
+
+	return score;
+}
+
 /* ========================================================= */
 
 /**
@@ -372,11 +404,14 @@ void lg_corpus_linkage_senses(Linkage linkage)
 	 * word 0. */
 	for (w=1; w<nwords; w++)
 	{
-		/* If the word is not inflected, then sent->word[w].d is NULL */
-		if (sent->word[w].d)
-			infword = sent->word[w].d->string;
-		else
-			infword = sent->word[w].string;
+		Disjunct *disj = sent->parse_info->chosen_disjuncts[w];
+
+		/* disj is NULL if word did not participate in parse */
+		if (NULL == disj)
+		{
+			continue;
+		}
+		infword = disj->string;
 
 		lifo->sense_list[w] = lg_corpus_senses(corp, infword, 
 		                        lifo->disjunct_list_str[w], w);
@@ -446,5 +481,3 @@ void lg_sense_delete(Linkage_info *lifo)
 }
 
 /* ======================= END OF FILE ===================== */
-
-
