@@ -81,8 +81,12 @@ link_public_api(int)
      parse_options_get_linkage_limit(Parse_Options opts);
 link_public_api(void)
      parse_options_set_disjunct_cost(Parse_Options opts, int disjunct_cost);
+link_public_api(void)
+     parse_options_set_disjunct_costf(Parse_Options opts, float disjunct_cost);
 link_public_api(int)
      parse_options_get_disjunct_cost(Parse_Options opts);
+link_public_api(float)
+     parse_options_get_disjunct_costf(Parse_Options opts);
 link_public_api(void)
      parse_options_set_min_null_count(Parse_Options opts, int null_count);
 link_public_api(int)
@@ -137,6 +141,10 @@ link_public_api(void)
      parse_options_set_allow_null(Parse_Options opts, int val);
 link_public_api(int)
      parse_options_get_allow_null(Parse_Options opts);
+link_public_api(void)
+     parse_options_set_use_cluster_disjuncts(Parse_Options opts, int val);
+link_public_api(int)
+     parse_options_get_use_cluster_disjuncts(Parse_Options opts);
 link_public_api(void)
      parse_options_set_display_walls(Parse_Options opts, int val);
 link_public_api(int)
@@ -289,7 +297,11 @@ link_public_api(const char **)
 link_public_api(const char **)
      linkage_get_words(Linkage linkage);
 link_public_api(const char *)
-     linkage_get_disjunct(Linkage linkage, int w);
+     linkage_get_disjunct_str(Linkage linkage, int w);
+link_public_api(double)
+     linkage_get_disjunct_cost(Linkage linkage, int w);
+link_public_api(double)
+     linkage_get_disjunct_corpus_score(Linkage linkage, int w);
 link_public_api(const char *)
      linkage_get_word(Linkage linkage, int w);
 link_public_api(char *)
